==> haskell-universe-base-1.1.4-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-universe-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 universe-base
version:              1.1.4
visibility:           public
id:                   universe-base-1.1.4-9tQp16mg5eR2UQ312pvwRl
key:                  universe-base-1.1.4-9tQp16mg5eR2UQ312pvwRl
license:              BSD-3-Clause
copyright:            2014 Daniel Wagner
maintainer:           me@dmwit.com
author:               Daniel Wagner
homepage:             https://github.com/dmwit/universe
synopsis:             A class for finite and recursively enumerable types.
description:
    A class for finite and recursively enumerable types and some helper functions for enumerating them.

    @
    class Universe a where universe :: [a]
    class Universe a => Finite a where universeF :: [a]; universeF = universe
    @

    This is slim package definiting only the type-classes and instances
    for types in GHC boot libraries.
    For more instances check @universe-instances-*@ packages.

category:             Data
abi:                  33c18afc90d0c1361eb948c269c2d736
exposed:              True
exposed-modules:
    Data.Universe.Class Data.Universe.Generic Data.Universe.Helpers

import-dirs:          /usr/lib/ghc-9.4.8/site-local/universe-base-1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/universe-base-1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/universe-base-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-universe-base
hs-libraries:         HSuniverse-base-1.1.4-9tQp16mg5eR2UQ312pvwRl
depends:
    base-4.17.2.1 containers-0.6.7 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-universe-base/html/universe-base.haddock

haddock-html:         /usr/share/doc/haskell-universe-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-universe-base-1.1.4-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-universe-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 universe-base
version:              1.1.4
visibility:           public
id:                   universe-base-1.1.4-7UCLedaTtdV28OYg4ZtKR8
key:                  universe-base-1.1.4-7UCLedaTtdV28OYg4ZtKR8
license:              BSD-3-Clause
copyright:            2014 Daniel Wagner
maintainer:           me@dmwit.com
author:               Daniel Wagner
homepage:             https://github.com/dmwit/universe
synopsis:             A class for finite and recursively enumerable types.
description:
    A class for finite and recursively enumerable types and some helper functions for enumerating them.

    @
    class Universe a where universe :: [a]
    class Universe a => Finite a where universeF :: [a]; universeF = universe
    @

    This is slim package definiting only the type-classes and instances
    for types in GHC boot libraries.
    For more instances check @universe-instances-*@ packages.

category:             Data
abi:                  3dbba0217c6e680b3d2c34db8729bb85
exposed:              True
exposed-modules:
    Data.Universe.Class Data.Universe.Generic Data.Universe.Helpers

import-dirs:          /usr/lib/ghc-9.4.8/site-local/universe-base-1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/universe-base-1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/universe-base-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-universe-base
hs-libraries:         HSuniverse-base-1.1.4-7UCLedaTtdV28OYg4ZtKR8
depends:
    base-4.17.2.1 containers-0.6.7 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-universe-base/html/universe-base.haddock

haddock-html:         /usr/share/doc/haskell-universe-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
